@@ -2,7 +2,7 @@
 
 #  ISC License
 #
-#  Copyright (c) 2020, Paul Wilhelm, M. Sc. <anfrage@paulwilhelm.de>
+#  Copyright (c) 2020–2021, Paul Wilhelm, M. Sc. <anfrage@paulwilhelm.de>
 #
 #  Permission to use, copy, modify, and/or distribute this software for any
 #  purpose with or without fee is hereby granted, provided that the above
@@ -19,32 +19,35 @@
 import numpy as np
 from numba import jit, prange, set_num_threads
 from magneticalc.Assert_Dialog import Assert_Dialog
+from magneticalc.Backend_Types import BACKEND_JIT, BACKEND_CUDA
 from magneticalc.BiotSavart_CUDA import BiotSavart_CUDA
 from magneticalc.BiotSavart_JIT import BiotSavart_JIT
 from magneticalc.Debug import Debug
+from magneticalc.Field_Types import A_FIELD, B_FIELD
 from magneticalc.Theme import Theme
 
 
 class Field:
     """ Field class. """
 
-    def __init__(self, backend: int, _type: int, distance_limit: float, length_scale: float):
+    def __init__(self, backend_type: int, field_type: int, distance_limit: float, length_scale: float):
         """
         Initializes an empty field.
 
-        @param backend: Backend index (0: JIT; 1: JIT + CUDA)
-        @param _type: Field type to display (0: A-field; 1: B-field)
+        @param backend_type: Backend type
+        @param field_type: Field type to display
         @param distance_limit: Distance limit (mitigating divisions by zero)
         @param length_scale: Length scale (m)
         """
         Debug(self, ": Init")
 
-        self._backend = backend
-        self._type = _type
+        self._backend_type = backend_type
+        self._field_type = field_type
         self._distance_limit = distance_limit
         self._length_scale = length_scale
 
-        self._total_limited = None
+        self._total_calculations = None
+        self._total_skipped_calculations = None
         self._vectors = None
 
     def is_valid(self) -> bool:
@@ -54,7 +57,8 @@ class Field:
         @return: True if data is valid for display, False otherwise
         """
         return \
-            self._total_limited is not None and \
+            self._total_calculations is not None and \
+            self._total_skipped_calculations is not None and \
             self._vectors is not None
 
     def invalidate(self):
@@ -63,16 +67,17 @@ class Field:
         """
         Debug(self, ".invalidate()", color=(128, 0, 0))
 
-        self._total_limited = None
+        self._total_calculations = None
+        self._total_skipped_calculations = None
         self._vectors = None
 
     def get_type(self) -> int:
         """
         Gets field type.
 
-        @return: Field type (0: A-field; 1: B-field)
+        @return: Field type
         """
-        return self._type
+        return self._field_type
 
     def get_units(self) -> str:
         """
@@ -80,10 +85,10 @@ class Field:
 
         @return: Field units
         """
-        return [
-            "Tm",   # A-field: Tesla · meter
-            "T"     # B-field: Tesla
-        ][self._type]
+        return {
+            A_FIELD: "Tm",  # Tesla · meter
+            B_FIELD: "T"    # Tesla
+        }.get(self._field_type, None)
 
     def get_vectors(self):
         """
@@ -95,15 +100,25 @@ class Field:
 
         return self._vectors
 
-    def get_total_limited(self) -> int:
+    def get_total_calculations(self) -> int:
         """
-        Gets total number of distance limited points.
+        Gets total number of calculations.
 
-        @return: Total number of distance limited points
+        @return: Total number of calculations
         """
         Assert_Dialog(self.is_valid(), "Accessing invalidated field")
 
-        return self._total_limited
+        return self._total_calculations
+
+    def get_total_skipped_calculations(self) -> int:
+        """
+        Gets total number of skipped calculations.
+
+        @return: Total number of skipped calculations
+        """
+        Assert_Dialog(self.is_valid(), "Accessing invalidated field")
+
+        return self._total_skipped_calculations
 
     # ------------------------------------------------------------------------------------------------------------------
 
@@ -118,8 +133,11 @@ class Field:
         @return: True if successful, False if interrupted (CUDA backend currently not interruptable)
         """
 
-        # Default to JIT backend if CUDA backend is selected but not available
-        if self._backend == 1:
+        # Compute the current elements.
+        current_elements = wire.get_elements()
+
+        # Default to JIT backend if CUDA backend is selected but not available.
+        if self._backend_type == BACKEND_CUDA:
             if not BiotSavart_CUDA.is_available():
                 Debug(
                     self,
@@ -127,17 +145,17 @@ class Field:
                     color=Theme.WarningColor,
                     force=True
                 )
-                self._backend = 0
+                self._backend_type = BACKEND_JIT
 
-        if self._backend == 0:
+        if self._backend_type == BACKEND_JIT:
 
             # Initialize Biot-Savart JIT backend
             biot_savart = BiotSavart_JIT(
-                self._type,
+                self._field_type,
                 self._distance_limit,
                 self._length_scale,
                 wire.get_dc(),
-                wire.get_elements(),
+                current_elements,
                 sampling_volume.get_points(),
                 sampling_volume.get_permeabilities(),
                 progress_callback
@@ -147,35 +165,36 @@ class Field:
             set_num_threads(num_cores)
             tup = biot_savart.get_result()
 
-        elif self._backend == 1:
+        elif self._backend_type == BACKEND_CUDA:
 
             # Initialize Biot-Savart CUDA backend
             biot_savart = BiotSavart_CUDA(
-                self._type,
+                self._field_type,
                 self._distance_limit,
                 self._length_scale,
                 wire.get_dc(),
-                wire.get_elements(),
+                current_elements,
                 sampling_volume.get_points(),
                 sampling_volume.get_permeabilities(),
                 progress_callback
             )
 
-            # Fetch result using Biot-Savart JIT backend
+            # Fetch result using Biot-Savart CUDA backend
             set_num_threads(num_cores)
             tup = biot_savart.get_result()
 
         else:
 
-            Debug(self, f".recalculate(): No such backend: {self._backend}", color=Theme.WarningColor, force=True)
+            Debug(self, f".recalculate(): No such backend: {self._backend_type}", color=Theme.WarningColor, force=True)
             return False
 
         # Handle interrupt
         if tup is None:
             return False
 
-        self._total_limited = tup[0]
-        self._vectors = tup[1]
+        self._total_calculations = tup[0]
+        self._total_skipped_calculations = tup[1]
+        self._vectors = tup[2]
 
         # Prints the sampling volume points, current elements and field vectors; may be used for debugging:
         """
@@ -188,12 +207,20 @@ class Field:
         import numpy
         numpy.set_printoptions(threshold=sys.maxsize)
 
-        print("sampling_volume_points =", print_array(sampling_volume.get_points()))
-        print("element_centers        =", print_array(element_centers))
-        print("element_directions     =", print_array(element_directions))
-        print("vectors          =", print_array(self._vectors))
+        print("Total calculations         =", self.get_total_calculations())
+        print("Total skipped calculations =", self.get_total_skipped_calculations())
+        print("sampling_volume_points     =", print_array(sampling_volume.get_points()))
+        print("element_centers            =", print_array(element_centers))
+        print("element_directions         =", print_array(element_directions))
+        print("vectors                    =", print_array(self._vectors))
         """
 
+        # Sanity check
+        expected_total_calculations = len(current_elements) * sampling_volume.get_points_count()
+        if expected_total_calculations != self._total_calculations:
+            Assert_Dialog(False, "FATAL: Unexpected number of calculations – Backend seems to be buggy")
+            return False
+
         return True
 
     # ------------------------------------------------------------------------------------------------------------------
